##  Accessing the Transformations Explorer
To access the transformations explorer, go to More > Transformations Explorer.
![Accessing the Transformations Explorer](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioc8b9c41acc284581aab564bbedb8b676_LowRes.png)
Accessing the Transformations Explorer
